@@ -31,7 +31,7 @@ class S(BaseHTTPRequestHandler):
             try:
                 q_params.append({"key": p.split("=")[0], "value": p.split("=")[1]})
             except Exception as es:
-                break
+                pass
 
         return q_params
 
@@ -46,22 +46,33 @@ class S(BaseHTTPRequestHandler):
                     and str(self.path).split("?")[0] == r["url_path"].split("?")[0]:
 
                 res = r["res"]
-                if body_params is not None:
+                if body_params is not None and bool(body_params) and r["type"] == "POST":
+                    system("rm -rf ./out && touch out")
                     # it's the good link
                     for cmd in r["command"]:
-                        if bool(body_params):
-                            for pr in r["body_params"]:
-                                cmd = cmd.replace("#{}#".format(pr), body_params[pr]) if "#"+pr+"#" in cmd else ""
-                        system(cmd)
+                        for pr in r["body_params"]:
+                            cmd = cmd.replace("#{}#".format(pr), body_params[pr]) if "#"+pr+"#" in cmd else ""
+                        system(cmd + " >> out")
+
+                    with open("./out", "r") as out_:
+                        out_content = out_.read()
+                        res = res.replace("#cmd#", out_content)
+                        system("rm -rf ./out")
 
                     for pr in r["body_params"]:
                         res = res.replace("#{}#".format(pr), body_params[pr]) if "#"+pr+"#" in res else res
                 else:
+                    system("rm -rf ./out && touch out")
                     # it's the good link
                     for cmd in r["command"]:
                         for p in q_params:
                             cmd = cmd.replace("#{}#".format(p["key"]), p["value"]) if "#"+p["key"]+"#" in cmd else ""
-                        system(cmd)
+                        system(cmd + " >> out")
+
+                    with open("./out", "r") as out_:
+                        out_content = out_.read()
+                        res = res.replace("#cmd#", out_content)
+                        system("rm -rf ./out")
 
                     for p in q_params:
                         res = res.replace("#{}#".format(p["key"]), p["value"]) if "#"+p["key"]+"#" in res else res
